The package esig provides a toolset (previously called sigtools) for transforming vector time series in stream space to signatures in effect space.
The software is strictly for evaluation only; all other rights reserved.